@@ -6,12 +6,13 @@
 
 #include "testhelper.h"
 
-#include "timelinedelegatecontroller.h"
 #include "applicationcontroller.h"
 #include "importcontroller.h"
 #include "livedatamanager.h"
 #include "reservationmanager.h"
+#include "timelinedelegatecontroller.h"
 #include "transfermanager.h"
+#include "tripgroupmanager.h"
 
 #include <KItinerary/Reservation>
 #include <KItinerary/TrainTrip>
@@ -19,15 +20,15 @@
 #include <KPublicTransport/Journey>
 #include <KPublicTransport/JourneyRequest>
 
+#include <QJSValue>
 #include <QJsonDocument>
 #include <QJsonObject>
-#include <QJSValue>
-#include <QUrl>
 #include <QQmlEngine>
-#include <QtTest/qtest.h>
 #include <QSignalSpy>
 #include <QStandardPaths>
 #include <QTimeZone>
+#include <QUrl>
+#include <QtTest/qtest.h>
 
 using namespace Qt::Literals::StringLiterals;
 using namespace KItinerary;
@@ -230,43 +231,59 @@ private Q_SLOTS:
         ldm.setReservationManager(&mgr);
         auto ctrl = Test::makeAppController();
         ctrl->setReservationManager(&mgr);
+        TransferManager trfMgr;
+        TripGroupManager tgMgr;
+        tgMgr.setReservationManager(&mgr);
+        tgMgr.setTransferManager(&trfMgr);
+        ctrl->setTripGroupManager(&tgMgr);
+
         ImportController importer;
         importer.setReservationManager(&mgr);
         importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/../tests/randa2017.json")));
         ctrl->commitImport(&importer);
+        QCOMPARE(tgMgr.tripGroups().size(), 1);
 
         TimelineDelegateController controller;
         controller.setReservationManager(&mgr);
         controller.setLiveDataManager(&ldm);
+        controller.setProperty("tripGroupManager", QVariant::fromValue(&tgMgr));
         controller.setBatchId(mgr.batches().at(mgr.batches().size() - 3)); // begin of the return train trip
         QCOMPARE(controller.isPublicTransport(), true);
         const auto batchCount = mgr.batches().size();
 
         QSignalSpy addSpy(&mgr, &ReservationManager::batchAdded);
         QSignalSpy updateSpy(&mgr, &ReservationManager::batchChanged);
+        QSignalSpy contentSpy(&mgr, &ReservationManager::batchContentChanged);
         QSignalSpy rmSpy(&mgr, &ReservationManager::batchRemoved);
 
         // apply alternative with 3 segments to test segment insertion
-        const auto jny3 = KPublicTransport::Journey::fromJson(QJsonDocument::fromJson(readFile(QLatin1StringView(SOURCE_DIR "/data/publictransport/randa-zrh-3-sections.json"))).object());
+        const auto jny3 = KPublicTransport::Journey::fromJson(
+            QJsonDocument::fromJson(readFile(QLatin1StringView(SOURCE_DIR "/data/publictransport/randa-zrh-3-sections.json"))).object());
         controller.applyJourney(QVariant::fromValue(jny3), true);
         QCOMPARE(mgr.batches().size(), batchCount + 1);
         QCOMPARE(addSpy.size(), 3);
         QCOMPARE(updateSpy.size(), 0); // as we move beyond other elements, we get add/remove rather than updated here
+        QCOMPARE(contentSpy.size(), 0);
         QCOMPARE(rmSpy.size(), 2);
         QCOMPARE(LiveData::listAll().size(), 3);
+        QCOMPARE(tgMgr.tripGroups().size(), 1);
 
         // apply alternative with 2 segments to test segment removal
         controller.setBatchId(mgr.batches().at(mgr.batches().size() - 3)); // begin of the new 3 segment train trip
         addSpy.clear();
         updateSpy.clear();
+        contentSpy.clear();
         rmSpy.clear();
-        const auto jny2 = KPublicTransport::Journey::fromJson(QJsonDocument::fromJson(readFile(QLatin1StringView(SOURCE_DIR "/data/publictransport/randa-zrh-2-sections.json"))).object());
+        const auto jny2 = KPublicTransport::Journey::fromJson(
+            QJsonDocument::fromJson(readFile(QLatin1StringView(SOURCE_DIR "/data/publictransport/randa-zrh-2-sections.json"))).object());
         controller.applyJourney(QVariant::fromValue(jny2), true);
         QCOMPARE(mgr.batches().size(), batchCount);
-        QCOMPARE(addSpy.size(), 2);
+        QCOMPARE(addSpy.size(), 0);
         QCOMPARE(updateSpy.size(), 0);
-        QCOMPARE(rmSpy.size(), 3);
+        QCOMPARE(contentSpy.size(), 2);
+        QCOMPARE(rmSpy.size(), 1);
         QCOMPARE(LiveData::listAll().size(), 2);
+        QCOMPARE(tgMgr.tripGroups().size(), 1);
     }
 
     void testCancel()
