@@ -15,7 +15,8 @@
 
 #include <limits>
 
-class WeatherForecastPrivate : public QSharedData {
+class WeatherForecastPrivate : public QSharedData
+{
 public:
     bool useDayTimeIcon() const;
 
@@ -34,9 +35,9 @@ WeatherForecast::WeatherForecast()
 {
 }
 
-WeatherForecast::WeatherForecast(const WeatherForecast&) = default;
+WeatherForecast::WeatherForecast(const WeatherForecast &) = default;
 WeatherForecast::~WeatherForecast() = default;
-WeatherForecast& WeatherForecast::operator=(const WeatherForecast&) = default;
+WeatherForecast &WeatherForecast::operator=(const WeatherForecast &) = default;
 
 bool WeatherForecast::isValid() const
 {
@@ -95,30 +96,29 @@ struct icon_map_t {
 };
 
 static const icon_map_t icon_map[] = {
-    { WeatherForecast::Snow, "weather-snow", "weather-snow" },
-    { WeatherForecast::LightSnow | WeatherForecast::Clear, "weather-snow-scattered-day", "weather-snow-scattered-night" },
-    { WeatherForecast::LightSnow, "weather-snow-scattered", "weather-snow-scattered" },
+    {WeatherForecast::Snow, "weather-snow", "weather-snow"},
+    {WeatherForecast::LightSnow | WeatherForecast::Clear, "weather-snow-scattered-day", "weather-snow-scattered-night"},
+    {WeatherForecast::LightSnow, "weather-snow-scattered", "weather-snow-scattered"},
 
-    { WeatherForecast::Hail, "weather-hail", "weather-hail" },
+    {WeatherForecast::Hail, "weather-hail", "weather-hail"},
 
-    { WeatherForecast::Clear | WeatherForecast::ThunderStorm, "weather-storm-day", "weather-storm-night" },
-    { WeatherForecast::ThunderStorm, "weather-storm", "weather-storm" },
+    {WeatherForecast::Clear | WeatherForecast::ThunderStorm, "weather-storm-day", "weather-storm-night"},
+    {WeatherForecast::ThunderStorm, "weather-storm", "weather-storm"},
 
-    { WeatherForecast::Clear | WeatherForecast::Rain, "weather-showers-day", "weather-showers-night" },
-    { WeatherForecast::Rain, "weather-showers", "weather-showers" },
-    { WeatherForecast::Clear | WeatherForecast::LightRain, "weather-showers-scattered-day", "weather-showers-scattered-night" },
-    { WeatherForecast::LightRain, "weather-showers-scattered", "weather-showers-scattered" },
+    {WeatherForecast::Clear | WeatherForecast::Rain, "weather-showers-day", "weather-showers-night"},
+    {WeatherForecast::Rain, "weather-showers", "weather-showers"},
+    {WeatherForecast::Clear | WeatherForecast::LightRain, "weather-showers-scattered-day", "weather-showers-scattered-night"},
+    {WeatherForecast::LightRain, "weather-showers-scattered", "weather-showers-scattered"},
 
-    { WeatherForecast::Clear | WeatherForecast::Clouds | WeatherForecast::Wind, "weather-clouds-wind", "weather-clouds-wind-night" },
-    { WeatherForecast::Clear | WeatherForecast::Clouds, "weather-clouds", "weather-clouds-night" },
-    { WeatherForecast::Clouds | WeatherForecast::Wind, "weather-many-clouds-wind", "weather-many-clouds-wind" },
-    { WeatherForecast::Clouds, "weather-many-clouds", "weather-many-clouds" },
-    { WeatherForecast::Fog, "weather-fog", "weather-fog" },
-    { WeatherForecast::LightClouds | WeatherForecast::Wind, "weather-few-clouds-wind", "weather-few-clouds-wind-night" },
-    { WeatherForecast::LightClouds, "weather-few-clouds", "weather-few-clouds-night" },
-    { WeatherForecast::Clear | WeatherForecast::Wind, "weather-clear-wind", "weather-clear-wind-night" },
-    { WeatherForecast::Clear, "weather-clear", "weather-clear-night" }
-};
+    {WeatherForecast::Clear | WeatherForecast::Clouds | WeatherForecast::Wind, "weather-clouds-wind", "weather-clouds-wind-night"},
+    {WeatherForecast::Clear | WeatherForecast::Clouds, "weather-clouds", "weather-clouds-night"},
+    {WeatherForecast::Clouds | WeatherForecast::Wind, "weather-many-clouds-wind", "weather-many-clouds-wind"},
+    {WeatherForecast::Clouds, "weather-many-clouds", "weather-many-clouds"},
+    {WeatherForecast::Fog, "weather-fog", "weather-fog"},
+    {WeatherForecast::LightClouds | WeatherForecast::Wind, "weather-few-clouds-wind", "weather-few-clouds-wind-night"},
+    {WeatherForecast::LightClouds, "weather-few-clouds", "weather-few-clouds-night"},
+    {WeatherForecast::Clear | WeatherForecast::Wind, "weather-clear-wind", "weather-clear-wind-night"},
+    {WeatherForecast::Clear, "weather-clear", "weather-clear-night"}};
 
 bool WeatherForecastPrivate::useDayTimeIcon() const
 {
@@ -247,7 +247,6 @@ bool WeatherForecast::isSevere() const
         return true;
     }
 
-
     return false;
 }
 
